@@ -7,17 +7,6 @@ to evaluate the system model.
 import energyscope.preprocessing.uq_estd as es
 
 
-def set_params():
-    """
-    Set the fixed parameters for each model evaluation.
-
-    """
-
-    params = []
-
-    return params
-
-
 def evaluate(x_in, params=[]):
     '''
     Evaluation of the system objectives for one given design.
