@@ -397,8 +397,8 @@ def load_case(run_dict, design_space, uq_bool=False, create_only_samples=False):
         if hasattr(case_description, 'set_params'):
             params = case_description.set_params()
         else:
-            params = []
-        params += [run_dict]
+            params = [run_dict]
+
     else:
         eval_func = None
         params = None
